@@ -29,6 +29,11 @@ click.UsageError.exit_code = USAGE_ERROR_CODE
 LOG = logging.getLogger(__name__)
 
 
+class GitLintUsageError(Exception):
+    """ Exception indicating there is an issue with how gitlint is used. """
+    pass
+
+
 def setup_logging():
     """ Setup gitlint logging """
     root_log = logging.getLogger("gitlint")
@@ -49,51 +54,50 @@ def log_system_info():
 
 
 def build_config(  # pylint: disable=too-many-arguments
-        ctx, target, config_path, c, extra_path, ignore, contrib, ignore_stdin, verbose, silent, debug
+        target, config_path, c, extra_path, ignore, contrib, ignore_stdin, staged, verbose, silent, debug
 ):
     """ Creates a LintConfig object based on a set of commandline parameters. """
     config_builder = LintConfigBuilder()
-    try:
-        # Config precedence:
-        # First, load default config or config from configfile
-        if config_path:
-            config_builder.set_from_config_file(config_path)
-        elif os.path.exists(DEFAULT_CONFIG_FILE):
-            config_builder.set_from_config_file(DEFAULT_CONFIG_FILE)
+    # Config precedence:
+    # First, load default config or config from configfile
+    if config_path:
+        config_builder.set_from_config_file(config_path)
+    elif os.path.exists(DEFAULT_CONFIG_FILE):
+        config_builder.set_from_config_file(DEFAULT_CONFIG_FILE)
 
-        # Then process any commandline configuration flags
-        config_builder.set_config_from_string_list(c)
+    # Then process any commandline configuration flags
+    config_builder.set_config_from_string_list(c)
 
-        # Finally, overwrite with any convenience commandline flags
-        if ignore:
-            config_builder.set_option('general', 'ignore', ignore)
+    # Finally, overwrite with any convenience commandline flags
+    if ignore:
+        config_builder.set_option('general', 'ignore', ignore)
 
-        if contrib:
-            config_builder.set_option('general', 'contrib', contrib)
+    if contrib:
+        config_builder.set_option('general', 'contrib', contrib)
 
-        if ignore_stdin:
-            config_builder.set_option('general', 'ignore-stdin', ignore_stdin)
+    if ignore_stdin:
+        config_builder.set_option('general', 'ignore-stdin', ignore_stdin)
 
-        if silent:
-            config_builder.set_option('general', 'verbosity', 0)
-        elif verbose > 0:
-            config_builder.set_option('general', 'verbosity', verbose)
+    if silent:
+        config_builder.set_option('general', 'verbosity', 0)
+    elif verbose > 0:
+        config_builder.set_option('general', 'verbosity', verbose)
 
-        if extra_path:
-            config_builder.set_option('general', 'extra-path', extra_path)
+    if extra_path:
+        config_builder.set_option('general', 'extra-path', extra_path)
 
-        if target:
-            config_builder.set_option('general', 'target', target)
+    if target:
+        config_builder.set_option('general', 'target', target)
 
-        if debug:
-            config_builder.set_option('general', 'debug', debug)
+    if debug:
+        config_builder.set_option('general', 'debug', debug)
 
-        config = config_builder.build()
+    if staged:
+        config_builder.set_option('general', 'staged', staged)
 
-        return config, config_builder
-    except LintConfigError as e:
-        click.echo(u"Config Error: {0}".format(ustr(e)))
-    ctx.exit(CONFIG_ERROR_CODE)  # return CONFIG_ERROR_CODE on config error
+    config = config_builder.build()
+
+    return config, config_builder
 
 
 def get_stdin_data():
@@ -130,22 +134,33 @@ def get_stdin_data():
 
 def build_git_context(lint_config, msg_filename, refspec):
     """ Builds a git context based on passed parameters and order of precedence """
+
+    # Determine which GitContext method to use if a custom message is passed
+    from_commit_msg = GitContext.from_commit_msg
+    if lint_config.staged:
+        LOG.debug("Fetching additional meta-data from staged commit")
+        from_commit_msg = lambda message: GitContext.from_staged_commit(message, lint_config.target)  # noqa
+
     # Order of precedence:
     # 1. Any data specified via --msg-filename
     if msg_filename:
-        LOG.debug("Attempting to read from --msg-filename.")
-        return GitContext.from_commit_msg(ustr(msg_filename.read()))
+        LOG.debug("Using --msg-filename.")
+        return from_commit_msg(ustr(msg_filename.read()))
 
     # 2. Any data sent to stdin (unless stdin is being ignored)
     if not lint_config.ignore_stdin:
         stdin_input = get_stdin_data()
         if stdin_input:
-            LOG.debug("Stdin data: %r", stdin_input)
-            LOG.debug("Stdin detected and not ignored. Will be used as input.")
-            return GitContext.from_commit_msg(stdin_input)
+            LOG.debug("Stdin data: '%s'", stdin_input)
+            LOG.debug("Stdin detected and not ignored. Using as input.")
+            return from_commit_msg(stdin_input)
+
+    if lint_config.staged:
+        raise GitLintUsageError(u"The 'staged' option (--staged) can only be used when using '--msg-filename' or "
+                                u"when piping data to gitlint via stdin.")
 
     # 3. Fallback to reading from local repository
-    LOG.debug("No --msg-filename flag, no or empty data passed to stdin. Attempting to read from the local repo.")
+    LOG.debug("No --msg-filename flag, no or empty data passed to stdin. Using the local repo.")
     return GitContext.from_local_repository(lint_config.target, refspec)
 
 
@@ -165,6 +180,7 @@ def build_git_context(lint_config, msg_filename, refspec):
 @click.option('--contrib', default="", help="Contrib rules to enable (comma-separated by id or name).")
 @click.option('--msg-filename', type=click.File(), help="Path to a file containing a commit-msg.")
 @click.option('--ignore-stdin', is_flag=True, help="Ignore any stdin data. Useful for running in CI server.")
+@click.option('--staged', is_flag=True, help="Read staged commit meta-info from the local repository.")
 @click.option('-v', '--verbose', count=True, default=0,
               help="Verbosity, more v's for more verbose output (e.g.: -v, -vv, -vvv). [default: -vvv]", )
 @click.option('-s', '--silent', help="Silent mode (no output). Takes precedence over -v, -vv, -vvv.", is_flag=True)
@@ -173,7 +189,7 @@ def build_git_context(lint_config, msg_filename, refspec):
 @click.pass_context
 def cli(  # pylint: disable=too-many-arguments
         ctx, target, config, c, commits, extra_path, ignore, contrib,
-        msg_filename, ignore_stdin, verbose, silent, debug,
+        msg_filename, ignore_stdin, staged, verbose, silent, debug,
 ):
     """ Git lint tool, checks your git commit messages for styling issues
 
@@ -189,8 +205,8 @@ def cli(  # pylint: disable=too-many-arguments
 
         # Get the lint config from the commandline parameters and
         # store it in the context (click allows storing an arbitrary object in ctx.obj).
-        config, config_builder = build_config(ctx, target, config, c, extra_path,
-                                              ignore, contrib, ignore_stdin, verbose, silent, debug)
+        config, config_builder = build_config(target, config, c, extra_path, ignore, contrib,
+                                              ignore_stdin, staged, verbose, silent, debug)
         LOG.debug(u"Configuration\n%s", ustr(config))
 
         ctx.obj = (config, config_builder, commits, msg_filename)
@@ -202,6 +218,12 @@ def cli(  # pylint: disable=too-many-arguments
     except GitContextError as e:
         click.echo(ustr(e))
         ctx.exit(GIT_CONTEXT_ERROR_CODE)
+    except GitLintUsageError as e:
+        click.echo(u"Error: {0}".format(ustr(e)))
+        ctx.exit(USAGE_ERROR_CODE)
+    except LintConfigError as e:
+        click.echo(u"Config Error: {0}".format(ustr(e)))
+        ctx.exit(CONFIG_ERROR_CODE)
 
 
 @cli.command("lint")
@@ -219,9 +241,10 @@ def lint(ctx):
     # where users are using --commits in a check job to check the commit messages inside a CI job. By returning 0, we
     # ensure that these jobs don't fail if for whatever reason the specified commit range is empty.
     if number_of_commits == 0:
-        LOG.debug(u'No commits in range "%s"', ctx.obj[2])
+        LOG.debug(u'No commits in range "%s"', refspec)
         ctx.exit(0)
 
+    LOG.debug(u'Linting %d commit(s)', number_of_commits)
     general_config_builder = ctx.obj[1]
     last_commit = gitcontext.commits[-1]
 
@@ -266,7 +289,6 @@ def install_hook(ctx):
     try:
         lint_config = ctx.obj[0]
         hooks.GitHookInstaller.install_commit_msg_hook(lint_config)
-        # declare victory :-)
         hook_path = hooks.GitHookInstaller.commit_msg_hook_path(lint_config)
         click.echo(u"Successfully installed gitlint commit-msg hook in {0}".format(hook_path))
         ctx.exit(0)
@@ -282,7 +304,6 @@ def uninstall_hook(ctx):
     try:
         lint_config = ctx.obj[0]
         hooks.GitHookInstaller.uninstall_commit_msg_hook(lint_config)
-        # declare victory :-)
         hook_path = hooks.GitHookInstaller.commit_msg_hook_path(lint_config)
         click.echo(u"Successfully uninstalled gitlint commit-msg hook from {0}".format(hook_path))
         ctx.exit(0)
