@@ -1,6 +1,10 @@
+# -*- coding: utf-8 -*-
+
+import copy
 import io
 import logging
 import os
+import re
 
 try:
     # python 2.x
@@ -41,11 +45,6 @@ class BaseTestCase(unittest.TestCase):
     EXPECTED_DIR = os.path.join(os.path.dirname(os.path.realpath(__file__)), "expected")
     GITLINT_USE_SH_LIB = os.environ.get("GITLINT_USE_SH_LIB", "[NOT SET]")
 
-    # List of 'git config' side-effects that can be used when mocking calls to git
-    GIT_CONFIG_SIDE_EFFECTS = [
-        u"#"  # git config --get core.commentchar
-    ]
-
     def setUp(self):
         self.logcapture = LogCapture()
         self.logcapture.setFormatter(logging.Formatter(LOG_FORMAT))
@@ -110,14 +109,54 @@ class BaseTestCase(unittest.TestCase):
             setattr(commit, attr, value)
         return commit
 
-    def assert_logged(self, lines):
-        """ Asserts that a certain list of messages has been logged """
-        self.assertListEqual(self.logcapture.messages, lines)
+    def assert_logged(self, expected):
+        """ Asserts that the logs match an expected string or list.
+            This method knows how to compare a passed list of log lines as well as a newline concatenated string
+            of all loglines. """
+        if isinstance(expected, list):
+            self.assertListEqual(self.logcapture.messages, expected)
+        else:
+            self.assertEqual("\n".join(self.logcapture.messages), expected)
 
     def assert_log_contains(self, line):
         """ Asserts that a certain line is in the logs """
         self.assertIn(line, self.logcapture.messages)
 
+    def assertRaisesRegex(self, expected_exception, expected_regex, *args, **kwargs):
+        """ Pass-through method to unittest.TestCase.assertRaisesRegex that applies re.escape() to the passed
+            `expected_regex`. This is useful to automatically escape all file paths that might be present in the regex.
+        """
+        return super(BaseTestCase, self).assertRaisesRegex(expected_exception, re.escape(expected_regex),
+                                                           *args, **kwargs)
+
+    def object_equality_test(self, obj, attr_list, ctor_kwargs=None):
+        """ Helper function to easily implement object equality tests.
+            Creates an object clone for every passed attribute and checks for (in)equality
+            of the original object with the clone based on those attributes' values.
+            This function assumes all attributes in `attr_list` can be passed to the ctor of `obj.__class__`.
+        """
+        if not ctor_kwargs:
+            ctor_kwargs = {}
+
+        attr_kwargs = {}
+        for attr in attr_list:
+            attr_kwargs[attr] = getattr(obj, attr)
+
+        # For every attr, clone the object and assert the clone and the original object are equal
+        # Then, change the current attr and assert objects are unequal
+        for attr in attr_list:
+            attr_kwargs_copy = copy.deepcopy(attr_kwargs)
+            attr_kwargs_copy.update(ctor_kwargs)
+            clone = obj.__class__(**attr_kwargs_copy)
+            self.assertEqual(obj, clone)
+
+            # Change attribute and assert objects are different (via both attribute set and ctor)
+            setattr(clone, attr, u"föo")
+            self.assertNotEqual(obj, clone)
+            attr_kwargs_copy[attr] = u"föo"
+
+            self.assertNotEqual(obj, obj.__class__(**attr_kwargs_copy))
+
 
 class LogCapture(logging.Handler):
     """ Mock logging handler used to capture any log messages during tests."""
