@@ -2,8 +2,9 @@
 # pylint: disable=too-many-function-args,unexpected-keyword-arg
 import io
 import os
-from sh import git, gitlint  # pylint: disable=no-name-in-module
-from qa.base import BaseTestCase, DEFAULT_ENCODING
+from qa.shell import echo, git, gitlint
+from qa.base import BaseTestCase
+from qa.utils import DEFAULT_ENCODING
 
 
 class IntegrationTests(BaseTestCase):
@@ -11,7 +12,7 @@ class IntegrationTests(BaseTestCase):
 
     def test_successful(self):
         # Test for STDIN with and without a TTY attached
-        self._create_simple_commit(u"Sïmple title\n\nSimple bödy describing the commit")
+        self.create_simple_commit(u"Sïmple title\n\nSimple bödy describing the commit")
         output = gitlint(_cwd=self.tmp_git_repo, _tty_in=True, _err_to_out=True)
         self.assertEqualStdout(output, "")
 
@@ -21,19 +22,19 @@ class IntegrationTests(BaseTestCase):
 
         # Different commentchar (Note: tried setting this to a special unicode char, but git doesn't like that)
         git("config", "--add", "core.commentchar", "$", _cwd=self.tmp_git_repo)
-        self._create_simple_commit(u"Sïmple title\n\nSimple bödy describing the commit\n$after commentchar\t ignored")
+        self.create_simple_commit(u"Sïmple title\n\nSimple bödy describing the commit\n$after commentchar\t ignored")
         output = gitlint(_cwd=self.tmp_git_repo, _tty_in=True, _err_to_out=True)
         self.assertEqualStdout(output, "")
 
     def test_successful_merge_commit(self):
         # Create branch on master
-        self._create_simple_commit(u"Cömmit on master\n\nSimple bödy")
+        self.create_simple_commit(u"Cömmit on master\n\nSimple bödy")
 
         # Create test branch, add a commit and determine the commit hash
         git("checkout", "-b", "test-branch", _cwd=self.tmp_git_repo)
         git("checkout", "test-branch", _cwd=self.tmp_git_repo)
         commit_title = u"Commit on test-brånch with a pretty long title that will cause issues when merging"
-        self._create_simple_commit(u"{0}\n\nSïmple body".format(commit_title))
+        self.create_simple_commit(u"{0}\n\nSïmple body".format(commit_title))
         hash = self.get_last_commit_hash()
 
         # Checkout master and merge the commit
@@ -54,7 +55,7 @@ class IntegrationTests(BaseTestCase):
 
     def test_fixup_commit(self):
         # Create a normal commit and assert that it has a violation
-        test_filename = self._create_simple_commit(u"Cömmit on WIP master\n\nSimple bödy that is long enough")
+        test_filename = self.create_simple_commit(u"Cömmit on WIP master\n\nSimple bödy that is long enough")
         output = gitlint(_cwd=self.tmp_git_repo, _tty_in=True, _ok_code=[1])
         expected = u"1: T5 Title contains the word 'WIP' (case-insensitive): \"Cömmit on WIP master\"\n"
         self.assertEqualStdout(output, expected)
@@ -83,9 +84,25 @@ class IntegrationTests(BaseTestCase):
 
         self.assertEqualStdout(output, expected)
 
+    def test_revert_commit(self):
+        self.create_simple_commit(u"WIP: Cömmit on master.\n\nSimple bödy")
+        hash = self.get_last_commit_hash()
+        git("revert", hash, _cwd=self.tmp_git_repo)
+
+        # Run gitlint and assert output is empty
+        output = gitlint(_cwd=self.tmp_git_repo, _tty_in=True)
+        self.assertEqualStdout(output, "")
+
+        # Assert that we do see the error if we disable the ignore-revert-commits option
+        output = gitlint("-c", "general.ignore-revert-commits=false",
+                         _cwd=self.tmp_git_repo, _tty_in=True, _ok_code=[1])
+        self.assertEqual(output.exit_code, 1)
+        expected = u"1: T5 Title contains the word 'WIP' (case-insensitive): \"Revert \"WIP: Cömmit on master.\"\"\n"
+        self.assertEqualStdout(output, expected)
+
     def test_squash_commit(self):
         # Create a normal commit and assert that it has a violation
-        test_filename = self._create_simple_commit(u"Cömmit on WIP master\n\nSimple bödy that is long enough")
+        test_filename = self.create_simple_commit(u"Cömmit on WIP master\n\nSimple bödy that is long enough")
         output = gitlint(_cwd=self.tmp_git_repo, _tty_in=True, _ok_code=[1])
         expected = u"1: T5 Title contains the word 'WIP' (case-insensitive): \"Cömmit on WIP master\"\n"
         self.assertEqualStdout(output, expected)
@@ -117,28 +134,18 @@ class IntegrationTests(BaseTestCase):
 
     def test_violations(self):
         commit_msg = u"WIP: This ïs a title.\nContent on the sëcond line"
-        self._create_simple_commit(commit_msg)
+        self.create_simple_commit(commit_msg)
         output = gitlint(_cwd=self.tmp_git_repo, _tty_in=True, _ok_code=[3])
-
-        expected = u"1: T3 Title has trailing punctuation (.): \"WIP: This ïs a title.\"\n" + \
-            u"1: T5 Title contains the word 'WIP' (case-insensitive): \"WIP: This ïs a title.\"\n" + \
-            u"2: B4 Second line is not empty: \"Content on the sëcond line\"\n"
-        self.assertEqualStdout(output, expected)
+        self.assertEqualStdout(output, self.get_expected("test_gitlint/test_violations_1"))
 
     def test_msg_filename(self):
-        tmp_commit_msg_file = self.create_tmpfile("WIP: msg-fïlename test.")
-
+        tmp_commit_msg_file = self.create_tmpfile(u"WIP: msg-fïlename test.")
         output = gitlint("--msg-filename", tmp_commit_msg_file, _tty_in=True, _ok_code=[3])
-
-        expected = u"1: T3 Title has trailing punctuation (.): \"WIP: msg-fïlename test.\"\n" + \
-            u"1: T5 Title contains the word 'WIP' (case-insensitive): \"WIP: msg-fïlename test.\"\n" + \
-            u"3: B6 Body message is missing\n"
-
-        self.assertEqualStdout(output, expected)
+        self.assertEqualStdout(output, self.get_expected("test_gitlint/test_msg_filename_1"))
 
     def test_msg_filename_no_tty(self):
         """ Make sure --msg-filename option also works with no TTY attached """
-        tmp_commit_msg_file = self.create_tmpfile("WIP: msg-fïlename NO TTY test.")
+        tmp_commit_msg_file = self.create_tmpfile(u"WIP: msg-fïlename NO TTY test.")
 
         # We need to set _err_to_out explicitly for sh to merge stdout and stderr output in case there's
         # no TTY attached to STDIN
@@ -148,8 +155,17 @@ class IntegrationTests(BaseTestCase):
         output = gitlint("--msg-filename", tmp_commit_msg_file, _in=" ",
                          _tty_in=False, _err_to_out=True, _ok_code=[3])
 
-        expected = u"1: T3 Title has trailing punctuation (.): \"WIP: msg-fïlename NO TTY test.\"\n" + \
-                   u"1: T5 Title contains the word 'WIP' (case-insensitive): \"WIP: msg-fïlename NO TTY test.\"\n" + \
-                   u"3: B6 Body message is missing\n"
+        self.assertEqualStdout(output, self.get_expected("test_gitlint/test_msg_filename_no_tty_1"))
 
+    def test_git_errors(self):
+        # Repo has no commits: caused by `git log`
+        empty_git_repo = self.create_tmp_git_repo()
+        output = gitlint(_cwd=empty_git_repo, _tty_in=True, _ok_code=[self.GIT_CONTEXT_ERROR_CODE])
+
+        expected = u"Current branch has no commits. Gitlint requires at least one commit to function.\n"
+        self.assertEqualStdout(output, expected)
+
+        # Repo has no commits: caused by `git rev-parse`
+        output = gitlint(echo(u"WIP: Pïpe test."), "--staged", _cwd=empty_git_repo, _tty_in=False,
+                         _err_to_out=True, _ok_code=[self.GIT_CONTEXT_ERROR_CODE])
         self.assertEqualStdout(output, expected)
