@@ -13,7 +13,7 @@ help(){
     echo "  -b, --build              Run build tests"
     echo "  -a, --all                Run all tests and checks (unit, integration, pep8, git)"
     echo "  -e, --envs [ENV1],[ENV2] Run tests against specified python environments"
-    echo "                           (envs: 27,34,35,36,37,pypy2,pypy35)."
+    echo "                           (envs: 27,35,36,37,pypy2,pypy35)."
     echo "                           Also works for integration, pep8 and lint tests."
     echo "  -C, --container          Run the specified command in the container for the --envs specified"
     echo "  --all-env                Run all tests against all python environments"
@@ -25,7 +25,7 @@ help(){
     echo "  -s, --stats              Show some project stats"
     echo "  --no-coverage            Don't make a unit test coverage report"
     echo ""
-    exit 0;
+    exit 0
 }
 
 RED="\033[31m"
@@ -39,7 +39,7 @@ title(){
     echo -e $MSG
 }
 
-subtitle() {
+subtitle(){
     MSG="$YELLOW$1$NO_COLOR"
     echo -e $MSG
 }
@@ -76,17 +76,9 @@ handle_test_result(){
 
 run_pep8_check(){
     # FLAKE 8
-    # H307: like imports should be grouped together
-    # H405: multi line docstring summary not separated with an empty line
-    # H803: git title must end with a period
-    # H904: Wrap long lines in parentheses instead of a backslash
-    # H802: git commit title should be under 50 chars
-    # H701: empty localization string
-    FLAKE8_IGNORE="H307,H405,H803,H904,H802,H701"
-    # exclude settings files and virtualenvs
-    FLAKE8_EXCLUDE="*settings.py,*.venv/*.py"
+    target=${testargs:-"gitlint qa examples"}
     echo -ne "Running flake8..."
-    RESULT=$(flake8 --ignore=$FLAKE8_IGNORE --max-line-length=120 --exclude=$FLAKE8_EXCLUDE gitlint qa examples)
+    RESULT=$(flake8 $target)
     local exit_code=$?
     handle_test_result $exit_code "$RESULT"
     return $exit_code
@@ -97,11 +89,8 @@ run_unit_tests(){
     # py.test -s  => print standard output (i.e. show print statement output)
     #         -rw => print warnings
     OMIT="*pypy*,*venv*,*virtualenv*,*gitlint/tests/*"
-    if [ -n "$testargs" ]; then
-        coverage run --omit=$OMIT -m pytest -rw -s "$testargs"
-    else
-        coverage run --omit=$OMIT -m pytest -rw -s gitlint
-    fi
+    target=${testargs:-"gitlint"}
+    coverage run --omit=$OMIT -m pytest -rw -s $target
     TEST_RESULT=$?
     if [ $include_coverage -eq 1 ]; then
         COVERAGE_REPORT=$(coverage report -m)
@@ -120,13 +109,14 @@ run_integration_tests(){
     # virtualenv's python binary path.
     export GIT_EXEC_PATH="$PATH"
 
+    echo ""
+    gitlint --version
+    echo -e "Using $(which gitlint)\n"
+
     # py.test -s => print standard output (i.e. show print statement output)
     #         -rw => print warnings
-    if [ -n "$testargs" ]; then
-        py.test -s "$testargs"
-    else
-        py.test -s qa/
-    fi
+    target=${testargs:-"qa/"}
+    py.test -s $target
 }
 
 run_git_check(){
@@ -140,7 +130,8 @@ run_git_check(){
 
 run_lint_check(){
     echo -ne "Running pylint...${RED}"
-    RESULT=$(pylint gitlint qa --rcfile=".pylintrc" -r n)
+    target=${testargs:-"gitlint qa"}
+    RESULT=$(pylint $target --rcfile=".pylintrc" -r n)
     local exit_code=$?
     handle_test_result $exit_code "$RESULT"
     return $exit_code
@@ -203,12 +194,21 @@ run_stats(){
     echo "    First commit: $(git log --pretty="%aD" $(git rev-list --max-parents=0 HEAD))"
     echo "    Contributors: $(git log --format='%aN' | sort -u | wc -l | tr -d ' ')"
     echo "    Releases (tags): $(git tag --list | wc -l | tr -d ' ')"
+    latest_tag=$(git tag --sort=creatordate | tail -n 1)
+    echo "    Latest Release (tag): $latest_tag"
+    echo "    Commits since $latest_tag: $(git log --format=oneline HEAD...$latest_tag | wc -l | tr -d ' ')"
+    echo "    Line changes since $latest_tag: $(git diff --shortstat $latest_tag)"
     # PyPi API: https://pypistats.org/api/
     echo "*** PyPi ***"
-    stats=$(curl -s https://pypistats.org/api/packages/gitlint/recent)
-    echo "    Last Month: $(echo $stats | jq .data.last_month)"
-    echo "    Last Week: $(echo $stats | jq .data.last_week)"
-    echo "    Last Day: $(echo $stats | jq .data.last_day)"
+    info=$(curl -Ls https://pypi.python.org/pypi/gitlint/json)
+    echo "    Current version: $(echo $info | jq -r .info.version)"
+    echo "*** PyPi (Downloads) ***"
+    overall_stats=$(curl -s https://pypistats.org/api/packages/gitlint/overall)
+    recent_stats=$(curl -s https://pypistats.org/api/packages/gitlint/recent)
+    echo "    Last 6 Months: $(echo $overall_stats | jq -r '.data[].downloads' | awk '{sum+=$1} END {print sum}')"
+    echo "    Last Month: $(echo $recent_stats | jq .data.last_month)"
+    echo "    Last Week: $(echo $recent_stats | jq .data.last_week)"
+    echo "    Last Day: $(echo $recent_stats | jq .data.last_day)"
 }
 
 clean(){
@@ -260,12 +260,12 @@ install_virtualenv(){
 
     # For pypy: custom path + fetch from the web if not installed (=distro agnostic)
     if [[ $version == *"pypy2"* ]]; then
-        python_binary="/opt/pypy2.7-v7.1.1-linux64/bin/pypy"
+        python_binary="/opt/pypy2.7-v7.3.0-linux64/bin/pypy"
         if [ ! -f $python_binary ]; then
             assert_root "Must be root to install pypy2.7, use sudo"
             title "### DOWNLOADING PYPY2 ($pypy_archive) ###"
             pushd "/opt"
-            pypy_archive="pypy2.7-v7.1.1-linux64.tar.bz2"
+            pypy_archive="pypy2.7-v7.3.0-linux64.tar.bz2"
             wget "https://bitbucket.org/pypy/pypy/downloads/$pypy_archive"
             title "### EXTRACTING PYPY TARBALL ($pypy_archive) ###"
             tar xvf $pypy_archive
@@ -297,7 +297,7 @@ install_virtualenv(){
 }
 
 container_name(){
-    echo "gitlint-python-$1"
+    echo "jorisroovers/gitlint:dev-python-$1"
 }
 
 start_container(){
@@ -341,7 +341,7 @@ install_container(){
     tmp_exit_code=$?
     if [ $tmp_exit_code -gt 0 ]; then
         subtitle "Building container image from python:${python_version_dotted}-stretch..."
-        docker build --build-arg python_version_dotted="$python_version_dotted" -t $container_name .
+        docker build -f Dockerfile.dev --build-arg python_version_dotted="$python_version_dotted" -t $container_name .
         exit_code=$?
     else
         subtitle "Building container image from python:${python_version_dotted}-stretch...SKIP (ALREADY-EXISTS)"
@@ -370,14 +370,24 @@ uninstall_container(){
 
 assert_specific_env(){
     if [ -z "$1" ] || [ "$1" == "default" ]; then
-        fatal "ERROR: Please specify one or more valid python environments using --envs: 27,34,35,36,37,pypy2,pypy35"
+        fatal "ERROR: Please specify one or more valid python environments using --envs: 27,35,36,37,pypy2,pypy35"
         exit 1
     fi
 }
 
 switch_env(){
     if [ "$1" != "default" ]; then
+        # If we activated a virtualenv within this script, deactivate it
         deactivate 2> /dev/null # deactivate any active environment
+
+        # If this script was run from within an existing virtualenv, manually remove the current VIRTUAL_ENV from the
+        # current path. This ensures that our PATH is clean of that virtualenv.
+        # Note that the 'deactivate' function from the virtualenv is not available here unless the script was invoked
+        # as 'source ./run_tests.sh').
+        # Thanks internet stranger! https://unix.stackexchange.com/a/496050/38465
+        if [ ! -z "$VIRTUAL_ENV" ]; then
+            export PATH=$(echo $PATH | tr ":" "\n" | grep -v "$VIRTUAL_ENV" | tr "\n" ":");
+        fi
         set -e # Let's error out if you try executing against a non-existing env
         source "/vagrant/.venv${1}/bin/activate"
         set +e
@@ -438,7 +448,7 @@ while [ "$#" -gt 0 ]; do
         --install-container) shift; just_install_container=1;;
         --uninstall-container) shift; just_uninstall_container=1;;
         --all-env) shift; envs="all";;
-        --C|--container) shift; container_enabled=1;;
+        -C|--container) shift; container_enabled=1;;
         --no-coverage)shift; include_coverage=0;;
         *) testargs="$1"; shift;
    esac
@@ -456,7 +466,7 @@ exit_code=0
 
 # If the users specified 'all', then just replace $envs with the list of all envs
 if [ "$envs" == "all" ]; then
-    envs="27,34,35,36,37,pypy2,pypy35"
+    envs="27,35,36,37,38,pypy2,pypy35"
 fi
 original_envs="$envs"
 envs=$(echo "$envs" | tr ',' '\n') # Split the env list on comma so we can loop through it
